@@ -1,7 +1,7 @@
 package Perinci::Sub::ConvertArgs::Argv;
 
-our $DATE = '2016-09-25'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2016-12-12'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -85,7 +85,7 @@ sub convert_args_to_argv {
             if ($args_prop->{$arg}{greedy}) {
                 my $sch = $args_prop->{$arg}{schema};
                 my $is_array_of_simple = $sch && $sch->[0] eq 'array' &&
-                    $sch->[1]{of} && is_simple($sch->[1]{of});
+                    is_simple($sch->[1]{of} // $sch->[1]{each_elem});
                 for my $el (@{ $iargs{$arg} }) {
                     $argv[$pos] = $is_array_of_simple ? $el : _encode($el);
                     $pos++;
@@ -102,6 +102,8 @@ sub convert_args_to_argv {
         my $is_bool = $sch && $sch->[0] eq 'bool';
         my $is_array_of_simple = $sch && $sch->[0] eq 'array' &&
             $sch->[1]{of} && is_simple($sch->[1]{of});
+        my $is_hash_of_simple = $sch && $sch->[0] eq 'hash' &&
+            is_simple($sch->[1]{of} // $sch->[1]{each_value} // $sch->[1]{each_elem});
         my $can_be_comma_separated = $is_array_of_simple &&
             $sch->[1]{of}[0] =~ /\A(int|float)\z/; # XXX as well as other simple types that cannot contain commas
         my $opt = $_; $opt =~ s/_/-/g;
@@ -118,6 +120,11 @@ sub convert_args_to_argv {
             for (@{ $iargs{$_} }) {
                 push @argv, "$dashopt", $_;
             }
+        } elsif ($is_hash_of_simple) {
+            my $arg = $iargs{$_};
+            for (sort keys %$arg) {
+                push @argv, "$dashopt", "$_=$arg->{$_}";
+            }
         } else {
             if (ref $iargs{$_}) {
                 push @argv, "$dashopt-json", _encode($iargs{$_});
@@ -144,7 +151,7 @@ Perinci::Sub::ConvertArgs::Argv - Convert hash arguments to command-line options
 
 =head1 VERSION
 
-This document describes version 0.09 of Perinci::Sub::ConvertArgs::Argv (from Perl distribution Perinci-Sub-ConvertArgs-Argv), released on 2016-09-25.
+This document describes version 0.10 of Perinci::Sub::ConvertArgs::Argv (from Perl distribution Perinci-Sub-ConvertArgs-Argv), released on 2016-12-12.
 
 =head1 SYNOPSIS
 
